@@ -61,7 +61,8 @@ static char sccsid[] = "@(#)fts.c	8.6 (Berkeley) 8/14/94";
 #   define _STAT_VER		0
 #   define __fxstat64(_stat_ver, _fd, _sbp) fstat64((_fd), (_sbp))
 #endif
-#ifdef __CYGWIN__
+#if defined(__CYGWIN__)
+#   define __errno_location()   (__errno())
 #   define __fxstat64(_stat_ver, _fd, _sbp)     fstat((_fd), (_sbp))
 #endif
 #include "system.h"
